<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sv_SE">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../ui/about.ui" line="165"/>
        <source>Supported image formats:</source>
        <translation>Fungerande filformat:</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="6"/>
        <source>About Wally</source>
        <translation>Om Wally</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="94"/>
        <source>Details &gt;&gt;</source>
        <translation>Detaljer &gt;&gt;</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="47"/>
        <source>Compiled with:</source>
        <translation>Kompilerat med:</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="49"/>
        <source>EXIF library:</source>
        <translation>EXIF bibliotek:</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="52"/>
        <source>present</source>
        <translation>närvarande</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="54"/>
        <source>not present</source>
        <translation>ej närvarande</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="74"/>
        <source>Chinese (Simplified)</source>
        <translation>Kinesiska (förenklad)</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="76"/>
        <source>Chinese (Traditional)</source>
        <translation>Kinesiska (traditionell)</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="78"/>
        <source>Polish</source>
        <translation>Polska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="80"/>
        <source>Catalan</source>
        <translation>Katalanska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="82"/>
        <source>Greek</source>
        <translation>Grekiska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="84"/>
        <source>Korean</source>
        <translation>Koreanska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="86"/>
        <source>Hungarian</source>
        <translation>Ungerska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="88"/>
        <source>Danish</source>
        <translation>Danska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="90"/>
        <source>Swedish</source>
        <translation>Svenska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="92"/>
        <source>Turkish</source>
        <translation>Turkiska</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="104"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="152"/>
        <source>Extension</source>
        <translation>Ändelse</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="157"/>
        <source>Description</source>
        <translation>Beskrivning</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="172"/>
        <source>Additional info:</source>
        <translation>Övrig information:</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="244"/>
        <source>Language</source>
        <translation>Språk</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="249"/>
        <source>Translator</source>
        <translation>Översättare</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="65"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;/head&gt;&lt;body&gt;&lt;font size=&quot;+1&quot;&gt;Qt4 desktop wallpaper changer&lt;br /&gt;Author: Antonio Di Monaco (a.k.a. &lt;i&gt;Sin(x) &apos;76&lt;/i&gt;)&lt;br /&gt;I&apos;d like to thank Vincent Willem van Gogh for the logo :)&lt;br /&gt;&lt;br /&gt;Web site: &lt;a href=&quot;http://www.becrux.com&quot;&gt;http://www.becrux.com&lt;/a&gt;&lt;br /&gt;You can contact me at &lt;a href=&quot;mailto:tony@becrux.com?subject=About Wally&quot;&gt;tony@becrux.com&lt;/font&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;/head&gt;&lt;body&gt;&lt;font size=&quot;+1&quot;&gt;Qt4 bakgrundsbytare&lt;br /&gt;Skapare: Antonio Di Monaco (a.k.a. &lt;i&gt;Sin(x) &apos;76&lt;/i&gt;)&lt;br /&gt;Jag vill tacka Vincent Willem van Gogh för loggotypen :)&lt;br /&gt;&lt;br /&gt;Hemsida: &lt;a href=&quot;http://www.becrux.com&quot;&gt;http://www.becrux.com&lt;/a&gt;&lt;br /&gt;Du kan kontakta mig på &lt;a href=&quot;mailto:tony@becrux.com?subject=About Wally&quot;&gt;tony@becrux.com&lt;/font&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="60"/>
        <source>Italian</source>
        <translation>Italienska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="58"/>
        <source>English</source>
        <translation>Engelska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="62"/>
        <source>Russian</source>
        <translation>Ryska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="64"/>
        <source>Spanish</source>
        <translation>Spanska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="66"/>
        <source>Portuguese (Brazil)</source>
        <translation>Portugisiska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="68"/>
        <source>German</source>
        <translation>Tyska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="70"/>
        <source>French</source>
        <translation>Franska</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="72"/>
        <source>Czech</source>
        <translation>Tjeckiska</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="257"/>
        <source>Translations:</source>
        <translation>Översättare:</translation>
    </message>
</context>
<context>
    <name>Bing::DialogWidget</name>
    <message>
        <location filename="../../src/bing.cpp" line="304"/>
        <source>All of these words</source>
        <translation>Alla dessa ord</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="305"/>
        <source>Any of these words</source>
        <translation>Vilket som helst av dessa ord</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="308"/>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="314"/>
        <source>Strict</source>
        <translation>Strikt</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="315"/>
        <source>Moderate</source>
        <translation>Mild</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="316"/>
        <source>Off</source>
        <translation>Av</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="319"/>
        <source>Adult filter:</source>
        <translation>Vuxen filter:</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="342"/>
        <source>Bing item</source>
        <translation>Bing objekt</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="343"/>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>Ofiltrerat innehåll kan visa känsliga eller sexuellt anspelande foton</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="354"/>
        <source>Edit Bing item</source>
        <translation>Modifiera Bing objekt</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="361"/>
        <source>Add Bing item</source>
        <translation>Lägg till Bing objekt</translation>
    </message>
</context>
<context>
    <name>Bing::Item</name>
    <message>
        <location filename="../../src/bing.cpp" line="56"/>
        <source>Tags:</source>
        <translation>Etiketter:</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="58"/>
        <source>and</source>
        <translation>och</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="58"/>
        <source>or</source>
        <translation>eller</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="59"/>
        <source>Adult filter:</source>
        <translation>Vuxen filter:</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="64"/>
        <source>Off</source>
        <translation>Av</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="68"/>
        <source>Moderate</source>
        <translation>Mild</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="73"/>
        <source>Strict</source>
        <translation>Strikt</translation>
    </message>
</context>
<context>
    <name>Buzznet::DialogWidget</name>
    <message>
        <location filename="../../src/buzznet.cpp" line="225"/>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <location filename="../../src/buzznet.cpp" line="248"/>
        <source>Edit Buzznet item</source>
        <translation>Modifiera Buzznet objekt</translation>
    </message>
    <message>
        <location filename="../../src/buzznet.cpp" line="253"/>
        <source>Add Buzznet item</source>
        <translation>Lägg till Buzznet objekt</translation>
    </message>
</context>
<context>
    <name>Buzznet::Item</name>
    <message>
        <location filename="../../src/buzznet.cpp" line="42"/>
        <source>Tag:</source>
        <translation>Etikett:</translation>
    </message>
</context>
<context>
    <name>DeviantArt::DialogWidget</name>
    <message>
        <location filename="../../src/deviantart.cpp" line="247"/>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="252"/>
        <source>Strict</source>
        <translation>Strikt</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="253"/>
        <source>Off</source>
        <translation>Av</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="256"/>
        <source>Adult filter:</source>
        <translation>Vuxen filter:</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="277"/>
        <source>deviantART item</source>
        <translation>deviantART objekt</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="278"/>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>Ofiltrerat innehåll kan visa känsliga eller sexuellt anspelande foton</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="289"/>
        <source>Edit deviantART item</source>
        <translation>Modifiera deviantART objekt</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="295"/>
        <source>Add deviantART item</source>
        <translation>Lägg till ett deviantART objekt</translation>
    </message>
</context>
<context>
    <name>DeviantArt::Item</name>
    <message>
        <location filename="../../src/deviantart.cpp" line="43"/>
        <source>Tag:</source>
        <translation>Etikett:</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="44"/>
        <source>Adult filter:</source>
        <translation>Vuxen filter:</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="49"/>
        <source>Off</source>
        <translation>Av</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="54"/>
        <source>Strict</source>
        <translation>Strikt</translation>
    </message>
</context>
<context>
    <name>Exif::InfoDialog</name>
    <message>
        <location filename="../../src/exif.cpp" line="260"/>
        <source>EXIF information</source>
        <translation>EXIF information</translation>
    </message>
    <message>
        <location filename="../../src/exif.cpp" line="274"/>
        <source>Tag</source>
        <translation>Etikett</translation>
    </message>
    <message>
        <location filename="../../src/exif.cpp" line="275"/>
        <source>Value</source>
        <translation>Värde</translation>
    </message>
    <message>
        <location filename="../../src/exif.cpp" line="298"/>
        <source>No EXIF information available</source>
        <translation>EXIF information inte tillgänglig</translation>
    </message>
</context>
<context>
    <name>Files::Core</name>
    <message>
        <location filename="../../src/files.cpp" line="145"/>
        <source>Loading folder...</source>
        <translation>Laddar mapp...</translation>
    </message>
</context>
<context>
    <name>Files::LabelPreview</name>
    <message>
        <location filename="../../src/files.cpp" line="261"/>
        <source>No preview available</source>
        <translation>Ingen förhandsvisning tillgänglig</translation>
    </message>
</context>
<context>
    <name>Files::SettingsWidget</name>
    <message>
        <location filename="../../src/files.cpp" line="281"/>
        <location filename="../../src/files.cpp" line="334"/>
        <source>Select a photo</source>
        <translation>Välj ett foto</translation>
    </message>
    <message>
        <location filename="../../src/files.cpp" line="297"/>
        <location filename="../../src/files.cpp" line="302"/>
        <source>Select a folder</source>
        <translation>Välj en mapp</translation>
    </message>
</context>
<context>
    <name>FilesSettingsWidget</name>
    <message>
        <location filename="../../ui/files.ui" line="15"/>
        <source>Photos</source>
        <translation>Foton</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="39"/>
        <source>Add a photo</source>
        <translation>Lägg till ett foto</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="59"/>
        <source>Add photos in folder</source>
        <translation>Lägg till foton från mapp</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="82"/>
        <source>Delete photo</source>
        <translation>Ta bort foto</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="118"/>
        <source>Move photo up</source>
        <translation>Flytta upp foto</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="141"/>
        <source>Move photo down</source>
        <translation>Flytta ner foto</translation>
    </message>
</context>
<context>
    <name>Flickr::DialogWidget</name>
    <message>
        <location filename="../../src/flickr.cpp" line="395"/>
        <source>All of these words</source>
        <translation>Alla dessa ord</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="396"/>
        <source>Any of these words</source>
        <translation>Vilket som helst av dessa ord</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="400"/>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="404"/>
        <source>Full text</source>
        <translation>Full text</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="405"/>
        <source>Tags only</source>
        <translation>Endast etiketter</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="413"/>
        <source>Largest</source>
        <translation>Störst</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="414"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="415"/>
        <source>Large</source>
        <translation>Stor</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="416"/>
        <source>Medium</source>
        <translation>Medel</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="417"/>
        <source>Small</source>
        <translation>Liten</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="418"/>
        <source>Thumbnail</source>
        <translation>Tumnagel</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="419"/>
        <source>Square</source>
        <translation>Ruta</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="420"/>
        <source>Smallest</source>
        <translation>Minst</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="426"/>
        <source>Relevance</source>
        <translation>Relevans</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="434"/>
        <source>Size:</source>
        <translation>Storlek:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="436"/>
        <source>Order:</source>
        <translation>Ordning:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="478"/>
        <source>Edit Flickr item</source>
        <translation>Ändra Flickr objekt</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="496"/>
        <source>Add Flickr item</source>
        <translation>Lägg till ett Flickr objekt</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="425"/>
        <source>Interestingness desc</source>
        <translation>Intresse, avtagande</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="427"/>
        <source>Date posted desc</source>
        <translation>Uppläggningsdatum, avtagande</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="428"/>
        <source>Date taken desc</source>
        <translation>c</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="429"/>
        <source>Interestingness asc</source>
        <translation>Intresse, stigande</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="430"/>
        <source>Date posted asc</source>
        <translation>Uppläggningsdatum, stigande</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="431"/>
        <source>Date taken asc</source>
        <translation>Fotograferingsdatum, stigande</translation>
    </message>
</context>
<context>
    <name>Flickr::Item</name>
    <message>
        <location filename="../../src/flickr.cpp" line="58"/>
        <source>Text:</source>
        <translation>Text:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="60"/>
        <source>Tags:</source>
        <translation>Etiketter:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="61"/>
        <source>and</source>
        <translation>och</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="62"/>
        <source>or</source>
        <translation>eller</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="66"/>
        <source>Size:</source>
        <translation>Storlek:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="69"/>
        <source>Largest</source>
        <translation>Störst</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="70"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="71"/>
        <source>Large</source>
        <translation>Stor</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="72"/>
        <source>Medium</source>
        <translation>Medel</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="73"/>
        <source>Small</source>
        <translation>Liten</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="74"/>
        <source>Thumbnail</source>
        <translation>Tumnagel</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="75"/>
        <source>Square</source>
        <translation>Ruta</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="76"/>
        <source>Smallest</source>
        <translation>Minst</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="79"/>
        <source>Order:</source>
        <translation>Ordning:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="83"/>
        <source>Relevance</source>
        <translation>Relevans</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="82"/>
        <source>Interestingness desc</source>
        <translation>Intresse, avtagande</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="84"/>
        <source>Date posted desc</source>
        <translation>Uppläggningsdatum, avtagande</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="85"/>
        <source>Date taken desc</source>
        <translation>Fotograferingsdatum, avtagande</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="86"/>
        <source>Interestingness asc</source>
        <translation>Intresse, stigande</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="87"/>
        <source>Date posted asc</source>
        <translation>Uppläggningsdatum, stigande</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="88"/>
        <source>Date taken asc</source>
        <translation>Fotograferingsdatum, stigande</translation>
    </message>
</context>
<context>
    <name>Folders::DialogWidget</name>
    <message>
        <location filename="../../src/folders.cpp" line="463"/>
        <source>Include subfolders</source>
        <translation>Inkludera underkataloger</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="534"/>
        <location filename="../../src/folders.cpp" line="539"/>
        <source>Select a folder</source>
        <translation>Välj en mapp</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="588"/>
        <source>Edit folder</source>
        <translation>Ändra mapp</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="614"/>
        <source>Add folder</source>
        <translation>Skapa ny mapp</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="447"/>
        <location filename="../../src/folders.cpp" line="456"/>
        <source>Local</source>
        <translation>Lokal</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="448"/>
        <location filename="../../src/folders.cpp" line="479"/>
        <source>Remote</source>
        <translation>Avlägsen</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="469"/>
        <source>Folder:</source>
        <translation>Mapp:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="488"/>
        <source>Passive</source>
        <translation>Passiv</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="489"/>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="501"/>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="503"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="505"/>
        <source>Transfer mode:</source>
        <translation>Överföringsläge:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="507"/>
        <source>Username:</source>
        <translation>Användarnamn:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="509"/>
        <source>Password:</source>
        <translation>Lösenord:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="511"/>
        <source>Path:</source>
        <translation>Adress:</translation>
    </message>
</context>
<context>
    <name>Folders::LocalItem</name>
    <message>
        <location filename="../../src/folders.cpp" line="149"/>
        <source>(with subfolders)</source>
        <translation>(med undermappar)</translation>
    </message>
</context>
<context>
    <name>Folders::RemoteItem</name>
    <message>
        <location filename="../../src/folders.cpp" line="253"/>
        <source>Transfer mode:</source>
        <translation>Överföringsläge:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="254"/>
        <source>passive</source>
        <translation>Passiv</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="254"/>
        <source>active</source>
        <translation>Aktiv</translation>
    </message>
</context>
<context>
    <name>FoldersSettingsWidget</name>
    <message>
        <location filename="../../ui/folders.ui" line="15"/>
        <source>Folders</source>
        <translation>Mappar</translation>
    </message>
    <message>
        <location filename="../../ui/folders.ui" line="26"/>
        <source>Add a folder</source>
        <translation>Lägg till en mapp</translation>
    </message>
    <message>
        <location filename="../../ui/folders.ui" line="49"/>
        <source>Delete folder</source>
        <translation>Ta bort mapp</translation>
    </message>
</context>
<context>
    <name>Google::DialogWidget</name>
    <message>
        <location filename="../../src/google.cpp" line="347"/>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="352"/>
        <source>Strict</source>
        <translation>Strikt</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="353"/>
        <source>Moderate</source>
        <translation>Mild</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="354"/>
        <source>Off</source>
        <translation>Av</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="357"/>
        <source>Adult filter:</source>
        <translation>Vuxen filter:</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="378"/>
        <source>Google item</source>
        <translation>Google objekt</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="379"/>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>Ofiltrerat innehåll kan visa känsliga eller sexuellt anspelande foton</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="390"/>
        <source>Edit Google item</source>
        <translation>Redigera Google objekt</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="396"/>
        <source>Add Google item</source>
        <translation>Lägg till ett Google objekt</translation>
    </message>
</context>
<context>
    <name>Google::Item</name>
    <message>
        <location filename="../../src/google.cpp" line="55"/>
        <source>Text:</source>
        <translation>Text:</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="56"/>
        <source>Adult filter:</source>
        <translation>Vuxen filter:</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="61"/>
        <source>Off</source>
        <translation>Av</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="65"/>
        <source>Moderate</source>
        <translation>Mild</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="70"/>
        <source>Strict</source>
        <translation>Strikt</translation>
    </message>
</context>
<context>
    <name>Gui::ColorButton</name>
    <message>
        <location filename="../../src/gui.cpp" line="132"/>
        <location filename="../../src/gui.cpp" line="140"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
</context>
<context>
    <name>History::Dialog</name>
    <message>
        <location filename="../../src/history.cpp" line="364"/>
        <source>Right-click on items to show options</source>
        <translation>Högerklicka på objekt för att visa alternativ</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="395"/>
        <location filename="../../src/history.cpp" line="596"/>
        <location filename="../../src/history.cpp" line="613"/>
        <source>History</source>
        <translation>Historik</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="440"/>
        <source>Please wait...</source>
        <translation>Vänligen vänta....</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="441"/>
        <source>Downloading photo...</source>
        <translation>Laddar ner foto...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="442"/>
        <source>Abort</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="454"/>
        <location filename="../../src/history.cpp" line="458"/>
        <source>Save photo</source>
        <translation>Spara foto</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="456"/>
        <location filename="../../src/history.cpp" line="461"/>
        <source>Images (*.png *.xpm *.jpg)</source>
        <translation>Bilder (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="596"/>
        <source>Photo has been saved</source>
        <translation>Fotot är sparat</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="613"/>
        <source>There was an error during download</source>
        <translation>Ett fel uppstod vid nedladdningen</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="663"/>
        <source>View photo...</source>
        <translation>Titta på foto...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="667"/>
        <source>Get EXIF info...</source>
        <translation>Hämta EXIF information...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="671"/>
        <source>Save photo...</source>
        <translation>Spara foto...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="675"/>
        <source>Set as background</source>
        <translation>Använd som bakgrund</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="679"/>
        <source>Explore image source</source>
        <translation>Undersök bildkälla</translation>
    </message>
</context>
<context>
    <name>History::EngineQueryModel</name>
    <message>
        <location filename="../../src/history.cpp" line="70"/>
        <source>All</source>
        <translation>Alla</translation>
    </message>
</context>
<context>
    <name>History::PhotosQueryModel</name>
    <message>
        <location filename="../../src/history.cpp" line="250"/>
        <source>Image size:</source>
        <translation>Bildstorlek:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="252"/>
        <source>Engine:</source>
        <translation>Motor:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="253"/>
        <source>EXIF:</source>
        <translation>EXIF:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="253"/>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="253"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="238"/>
        <source>(no title)</source>
        <translation>(ingen titel)</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="240"/>
        <source>by:</source>
        <translation>av:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="241"/>
        <source>(no author)</source>
        <translation>(ingen författare)</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="245"/>
        <source>Location:</source>
        <translation>Plats:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="246"/>
        <source>unknown</source>
        <translation>okänd</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="248"/>
        <source>Size:</source>
        <translation>Storlek:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="243"/>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
</context>
<context>
    <name>History::TagsQueryModel</name>
    <message>
        <location filename="../../src/history.cpp" line="99"/>
        <source>All</source>
        <translation>Alla</translation>
    </message>
</context>
<context>
    <name>HttpEngine::SettingsWidget</name>
    <message>
        <location filename="../../src/httpengine.cpp" line="656"/>
        <location filename="../../src/httpengine.cpp" line="661"/>
        <source>Select a folder</source>
        <translation>Välj en mapp</translation>
    </message>
</context>
<context>
    <name>HttpSettingsWidget</name>
    <message>
        <location filename="../../ui/http.ui" line="12"/>
        <source>Photo sets</source>
        <translation>Foto grupp</translation>
    </message>
    <message>
        <location filename="../../ui/http.ui" line="97"/>
        <source>Options</source>
        <translation>Alternativ</translation>
    </message>
    <message>
        <location filename="../../ui/http.ui" line="103"/>
        <source>Save photos</source>
        <translation>Spara foton</translation>
    </message>
    <message>
        <location filename="../../ui/http.ui" line="20"/>
        <source>Add a photo set</source>
        <translation>Lägg till en fotogrupp</translation>
    </message>
    <message>
        <location filename="../../ui/http.ui" line="43"/>
        <source>Delete photo set</source>
        <translation>Ta bort en fotongrupp</translation>
    </message>
</context>
<context>
    <name>Ipernity::DialogWidget</name>
    <message>
        <location filename="../../src/ipernity.cpp" line="284"/>
        <source>All of these words</source>
        <translation>Alla dessa ord</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="285"/>
        <source>Any of these words</source>
        <translation>Vilket som helst av dessa ord</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="288"/>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="292"/>
        <source>Full text</source>
        <translation>Full text</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="293"/>
        <source>Tags only</source>
        <translation>Endast etiketter</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="309"/>
        <source>Ipernity item</source>
        <translation>Ipernity objekt</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="310"/>
        <source>It can show offending or sexual explicit photos</source>
        <translation>Detta kan visa kränkande eller sexuellt anspelande foton</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="331"/>
        <source>Edit Ipernity item</source>
        <translation>Redigera Ipernity objekt</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="347"/>
        <source>Add Ipernity item</source>
        <translation>Lägg till ett Ipernity objekt</translation>
    </message>
</context>
<context>
    <name>Ipernity::Item</name>
    <message>
        <location filename="../../src/ipernity.cpp" line="57"/>
        <source>Text:</source>
        <translation>Text:</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="58"/>
        <location filename="../../src/ipernity.cpp" line="63"/>
        <source>and</source>
        <translation>och</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="59"/>
        <location filename="../../src/ipernity.cpp" line="64"/>
        <source>or</source>
        <translation>eller</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="66"/>
        <source>Tags:</source>
        <translation>Etiketter:</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../../src/main.cpp" line="65"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="68"/>
        <source>is already running</source>
        <translation>körs redan</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="77"/>
        <source>Disclaimer</source>
        <translation>Ansvarsfriskrivning</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="78"/>
        <source>&lt;b&gt;The Author takes no responsibility over the content that Wally downloads from photo sharing web sites.&lt;br&gt;The Author is in no way responsible for any such content.&lt;/b&gt;&lt;br&gt;&lt;br&gt;If this is a problem for you, please use only local engines like &quot;Files&quot; or local &quot;Folders&quot;.&lt;br&gt;Otherwise, please select &lt;b&gt;&quot;No&quot;&lt;/b&gt; to exit Wally, or use it &lt;b&gt;at your own risk.&lt;/b&gt;&lt;br&gt;&lt;br&gt;(If you proceed, this message will appear only once)&lt;br&gt;&lt;br&gt;Do you accept the above condition?</source>
        <translation>&lt;b&gt;Upphovsmannen tar inget ansvar för innehållet som Wally laddar ner från bilddelningssidor.&lt;br&gt;Upphovsmannen är på intet sätt ansvarig för något innehåll.&lt;/b&gt;&lt;br&gt;&lt;br&gt;Om detta är till problem för dig, vänligen använd endastlokala källor såsom &quot;Filer&quot; och lokala &quot;Mappar&quot;.&lt;br&gt;Välj annars&lt;b&gt;&quot;Nej&quot;&lt;/b&gt; för att avsluta Wally, eller använd det &lt;b&gt;på egen risk&lt;/b&gt;&lt;br&gt;&lt;br&gt;(om du fortsätter kommer detta meddelande bara visas en gång)&lt;br&gt;&lt;br&gt;Accepterar du dessa villkor?</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="66"/>
        <source>Another instance of</source>
        <translation>En annan instans av</translation>
    </message>
</context>
<context>
    <name>Map::View</name>
    <message>
        <location filename="../../src/mapviewer.cpp" line="387"/>
        <source>Drag to select. Right-click to zoom</source>
        <translation>Dra för att markera. Högerklicka för att zooma</translation>
    </message>
    <message>
        <location filename="../../src/mapviewer.cpp" line="395"/>
        <source>Zoom %1x</source>
        <translation>Zooma %1x</translation>
    </message>
</context>
<context>
    <name>Map::Viewer</name>
    <message>
        <location filename="../../src/mapviewer.cpp" line="434"/>
        <source>Map viewer</source>
        <translatorcomment>Mapa</translatorcomment>
        <translation>Kartvy</translation>
    </message>
</context>
<context>
    <name>Panoramio::DialogWidget</name>
    <message>
        <location filename="../../src/panoramio.cpp" line="322"/>
        <source>Select on map</source>
        <translation>Välj på karta</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="328"/>
        <source>Longitude (min):</source>
        <translation>Longitud (min):</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="330"/>
        <source>Longitude (max):</source>
        <translation>Longitud (max):</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="332"/>
        <source>Latitude (min):</source>
        <translation>Latitud (min):</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="334"/>
        <source>Latitude (max):</source>
        <translation>Latitud (max):</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="352"/>
        <source>Popularity</source>
        <translation>Popularitet</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="353"/>
        <source>Upload date</source>
        <translation>Uppladdningsdatum</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="358"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="359"/>
        <source>Medium</source>
        <translation>Medel</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="360"/>
        <source>Small</source>
        <translation>Liten</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="361"/>
        <source>Thumbnail</source>
        <translation>Tumnagel</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="362"/>
        <source>Square</source>
        <translation>Ruta</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="363"/>
        <source>Mini square</source>
        <translation>Mini ruta</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="366"/>
        <source>Order:</source>
        <translation>Ordning:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="367"/>
        <source>Size:</source>
        <translation>Storlek:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="414"/>
        <source>Edit Panoramio item</source>
        <translation>Redigera Panoramio objekt</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="427"/>
        <source>Add Panoramio item</source>
        <translation>Lägg till ett Panoramio objekt</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="435"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="435"/>
        <source>Coordinates must be different</source>
        <translation>Koordinaterna måste vara annorlunda</translation>
    </message>
</context>
<context>
    <name>Panoramio::Item</name>
    <message>
        <location filename="../../src/panoramio.cpp" line="284"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="285"/>
        <source>Medium</source>
        <translation>Medel</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="286"/>
        <source>Small</source>
        <translation>Liten</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="287"/>
        <source>Thumbnail</source>
        <translation>Tumnagel</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="288"/>
        <source>Square</source>
        <translation>Ruta</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="289"/>
        <source>Mini square</source>
        <translation>Mini ruta</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="294"/>
        <source>Popularity</source>
        <translation>Popularitet</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="295"/>
        <source>Upload date</source>
        <translation>Uppladdningsdatum</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="298"/>
        <source>Longitude:</source>
        <translation>Longitud:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="301"/>
        <source>Latitude:</source>
        <translation>Latitud:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="304"/>
        <source>Size:</source>
        <translation>Storlek:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="305"/>
        <source>Order:</source>
        <translation>Ordning:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="185"/>
        <source>lat:</source>
        <translation>lat:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="186"/>
        <source>lon:</source>
        <translation>long:</translation>
    </message>
</context>
<context>
    <name>Photobucket::DialogWidget</name>
    <message>
        <location filename="../../src/photobucket.cpp" line="279"/>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="293"/>
        <source>Photobucket item</source>
        <translation>Photobucket objekt</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="294"/>
        <source>It can show offending or sexual explicit photos</source>
        <translation>Detta kan vissa kränkande eller sexuellt anspelande bilder</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="311"/>
        <source>Edit Photobucket item</source>
        <translation>Redigera Photobucket objekt</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="317"/>
        <source>Add Photobucket item</source>
        <translation>Lägg till ett Photobucket objekt</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="275"/>
        <source>All of these words</source>
        <translation>Alla dessa ord</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="276"/>
        <source>Any of these words</source>
        <translation>Vilket som helst av dessa ord</translation>
    </message>
</context>
<context>
    <name>Photobucket::Item</name>
    <message>
        <location filename="../../src/photobucket.cpp" line="81"/>
        <source>Text:</source>
        <translation>Text:</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="82"/>
        <source>and</source>
        <translation>och</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="83"/>
        <source>or</source>
        <translation>eller</translation>
    </message>
</context>
<context>
    <name>Picasa::DialogWidget</name>
    <message>
        <location filename="../../src/picasa.cpp" line="255"/>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <location filename="../../src/picasa.cpp" line="278"/>
        <source>Edit Picasa item</source>
        <translation>Redigera Picasa objekt</translation>
    </message>
    <message>
        <location filename="../../src/picasa.cpp" line="283"/>
        <source>Add Picasa item</source>
        <translation>Lägg till ett Picasa objekt</translation>
    </message>
</context>
<context>
    <name>Picasa::Item</name>
    <message>
        <location filename="../../src/picasa.cpp" line="47"/>
        <source>Text:</source>
        <translation>Text:</translation>
    </message>
</context>
<context>
    <name>Pikeo::DialogWidget</name>
    <message>
        <location filename="../../src/pikeo.cpp" line="268"/>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="273"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="274"/>
        <source>Most viewed</source>
        <translation>Mest sedda</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="275"/>
        <source>Upload date</source>
        <translation>Uppladdningsdatum</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="276"/>
        <source>Date taken</source>
        <translation>Fotograferingsdatum</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="277"/>
        <source>Group add date</source>
        <translation>Tilläggningsdatum för grupp</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="278"/>
        <source>Comment date</source>
        <translation>Kommentars datum</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="282"/>
        <source>Ascending</source>
        <translation>Stigande</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="284"/>
        <source>Order:</source>
        <translation>Ordning:</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="315"/>
        <source>Edit Pikeo item</source>
        <translation>Redigera Pikeo objekt</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="322"/>
        <source>Add Pikeo item</source>
        <translation>Lägg till ett Pikeo objekt</translation>
    </message>
</context>
<context>
    <name>Pikeo::Item</name>
    <message>
        <location filename="../../src/pikeo.cpp" line="56"/>
        <source>Tags:</source>
        <translation>Etiketter:</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="57"/>
        <source>Order:</source>
        <translation>Ordning:</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="61"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="62"/>
        <source>Most viewed</source>
        <translation>Mest sedda</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="63"/>
        <source>Upload date</source>
        <translatorcomment>subida o carga?</translatorcomment>
        <translation>Uppladdningsdatum</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="64"/>
        <source>Date taken</source>
        <translation>Fotograferingsdatum</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="65"/>
        <source>Group add date</source>
        <translation>Tilläggningsdatum för grupp</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="66"/>
        <source>Comment date</source>
        <translation>Kommentars datum</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="69"/>
        <source>ascending</source>
        <translation>stigande</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="69"/>
        <source>descending</source>
        <translation>avtagande</translation>
    </message>
</context>
<context>
    <name>PositionModel</name>
    <message>
        <location filename="../../src/settings.cpp" line="133"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="136"/>
        <source>Picture smaller than screen on the left, greater than screen on the right</source>
        <translation>Bild mindre än skärm till vänster, större än skärm till höger</translation>
    </message>
</context>
<context>
    <name>QColorDialog</name>
    <message>
        <location filename="../../src/settings.cpp" line="184"/>
        <source>Hu&amp;e:</source>
        <translation>&amp;Ton:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="185"/>
        <source>&amp;Sat:</source>
        <translation>&amp;Mättnad:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="186"/>
        <source>&amp;Val:</source>
        <translation>&amp;Värde:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="187"/>
        <source>&amp;Red:</source>
        <translation>&amp;Röd:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="188"/>
        <source>&amp;Green:</source>
        <translation>&amp;Grön:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="189"/>
        <source>Bl&amp;ue:</source>
        <translation>&amp;Blå:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="190"/>
        <source>Select Color</source>
        <translation>Välj färg</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="191"/>
        <source>&amp;Basic colors</source>
        <translation>&amp;Standard färger</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="192"/>
        <source>&amp;Custom colors</source>
        <translation>&amp;Egna färger</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="193"/>
        <source>&amp;Add to Custom Colors</source>
        <translation>&amp;Lägg till i Egna färger</translation>
    </message>
</context>
<context>
    <name>QDialogButtonBox</name>
    <message>
        <location filename="../../src/settings.cpp" line="176"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="177"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="178"/>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="179"/>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="180"/>
        <source>&amp;No</source>
        <translation>&amp;Nej</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="181"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="182"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
</context>
<context>
    <name>QFileDialog</name>
    <message>
        <location filename="../../src/settings.cpp" line="195"/>
        <source>Directories</source>
        <translation>Mappar</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="196"/>
        <source>&amp;Open</source>
        <translation>&amp;Öppna</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="197"/>
        <source>&amp;Save</source>
        <translation>&amp;Spara</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="198"/>
        <source>Open</source>
        <translation>Öppna</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="199"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 Existerar redan.
Vill du ersätta?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="200"/>
        <source>%1
File not found.
Please verify the correct file name was given.</source>
        <translation>%1
Filen kan inte hittas
Vänligen verifiera att rätt filnamn angivits.</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="201"/>
        <source>My Computer</source>
        <translation>Min dator</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="202"/>
        <source>&amp;Rename</source>
        <translation>&amp;Byt namn</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="203"/>
        <source>&amp;Delete</source>
        <translation>&amp;Ta bort</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="204"/>
        <source>Show &amp;hidden files</source>
        <translation>&amp;Visa dolda filer</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="205"/>
        <source>Back</source>
        <translation>Tillbaka</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="206"/>
        <source>Parent Directory</source>
        <translation>Överliggande mapp</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="207"/>
        <source>List View</source>
        <translation>Visa lista</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="208"/>
        <source>Detail View</source>
        <translation>Detaljerad vy</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="209"/>
        <source>Files of type:</source>
        <translation>Filer av typen:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="210"/>
        <source>Directory:</source>
        <translation>Mapp:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="211"/>
        <source>%1
Directory not found.
Please verify the correct directory name was given.</source>
        <translation>%1
Kunde inte hitta mapp.
Vänligen kontrollera att namnet stämmer.</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="212"/>
        <source>&apos;%1&apos; is write protected.
Do you want to delete it anyway?</source>
        <translation>&apos;%1&apos; är skrivskyddad.
Vill du ta bort ändå?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="213"/>
        <source>Are sure you want to delete &apos;%1&apos;?</source>
        <translation>Är du säker på att du vill ta bort &apos;%1&apos;?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="214"/>
        <source>Could not delete directory.</source>
        <translation>Kunde inte ta bort katalog.</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="215"/>
        <source>Recent Places</source>
        <translation>Tidigare platser</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="216"/>
        <source>Save As</source>
        <translation>Spara som</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="217"/>
        <source>Drive</source>
        <translation>Disk</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="218"/>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="219"/>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="220"/>
        <source>Find Directory</source>
        <translation>Sök katalog</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="221"/>
        <source>Show</source>
        <translation>Visa</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="222"/>
        <source>Forward</source>
        <translation>Framåt</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="223"/>
        <source>New Folder</source>
        <translation>Ny mapp</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="224"/>
        <source>&amp;New Folder</source>
        <translation>&amp;Ny mapp</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="225"/>
        <source>&amp;Choose</source>
        <translation>&amp;Välj</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="226"/>
        <source>Remove</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="227"/>
        <source>File &amp;name:</source>
        <translation>Mapp &amp;namn:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="228"/>
        <source>Look in:</source>
        <translation>Titta i:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="229"/>
        <source>Create New Folder</source>
        <translation>Skapa ny mapp</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/utils.cpp" line="76"/>
        <source>All image files</source>
        <translation>Alla bildfiler</translation>
    </message>
    <message>
        <location filename="../../src/utils.cpp" line="80"/>
        <source>files</source>
        <translation>filer</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="31"/>
        <source>Centered</source>
        <translation>Centrerad</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="34"/>
        <source>Tiled</source>
        <translation>Kaklad</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="37"/>
        <source>Center Tiled</source>
        <translation>Centrerat kaklad</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="40"/>
        <source>Centered Maxpect</source>
        <translation>Proportionellt centrerad</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="43"/>
        <source>Tiled Maxpect</source>
        <translation>Proportionellt kaklad</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="46"/>
        <source>Scaled</source>
        <translation>Skalad</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="49"/>
        <source>Centered Auto Fit</source>
        <translation>Centrerad autojusterad</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="52"/>
        <source>Scale &amp; Crop</source>
        <translation>Skala &amp; Beskär</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="55"/>
        <source>Symmetrical Tiled</source>
        <translation>Symmetrisk mosaik</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="58"/>
        <source>Mirrored Tiled</source>
        <translation>Speglad mosaik</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="61"/>
        <source>Symmetrical Mirrored Tiled</source>
        <translation>Symmetrisk speglad mosaik</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <location filename="../../src/history.cpp" line="340"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../src/settings.cpp" line="243"/>
        <source>kBytes</source>
        <translation>kBytes</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="244"/>
        <source>MBytes</source>
        <translation>MBytes</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="245"/>
        <source>GBytes</source>
        <translation>GBytes</translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="248"/>
        <source>day(s)</source>
        <translation>
            <numerusform>dag</numerusform>
            <numerusform>dagar</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="249"/>
        <source>month(s)</source>
        <translation>
            <numerusform>månad</numerusform>
            <numerusform>månader</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="299"/>
        <location filename="../../src/settings.cpp" line="524"/>
        <source>second(s)</source>
        <translation>
            <numerusform>sekund</numerusform>
            <numerusform>sekunder</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="300"/>
        <location filename="../../src/settings.cpp" line="525"/>
        <source>minute(s)</source>
        <translation>
            <numerusform>minut</numerusform>
            <numerusform>minuter</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="301"/>
        <location filename="../../src/settings.cpp" line="526"/>
        <source>hour(s)</source>
        <translation>
            <numerusform>timme</numerusform>
            <numerusform>timmar</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="453"/>
        <source>Set position</source>
        <translation>Sätt position</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="599"/>
        <source>Clear history</source>
        <translation>Rensa historik</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="599"/>
        <source>Are you sure?</source>
        <translation>Är du säker?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="168"/>
        <location filename="../../src/settings.cpp" line="173"/>
        <location filename="../../src/settings.cpp" line="514"/>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="34"/>
        <source>General options</source>
        <translation>Generella alternativ</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="42"/>
        <source>Interval:</source>
        <translation>Intervall:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="69"/>
        <source>Border:</source>
        <translation>Kant:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="86"/>
        <location filename="../../ui/settings.ui" line="237"/>
        <source>Position:</source>
        <translation>Position:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="144"/>
        <source>Main</source>
        <translation>Huvudmeny</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="153"/>
        <source>Choose in random order</source>
        <translation>Välj slumpartad ordning</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="160"/>
        <source>Switch background on play</source>
        <translation>Byt bakgrund vid körning</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="167"/>
        <source>Play automatically on application start</source>
        <translation>Kör automatiskt vid programstart</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="174"/>
        <source>Disable splash screen</source>
        <translation>Visa startskärm</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="181"/>
        <source>Quit after background change</source>
        <translation>Stäng av efter bakgrundsbyte</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="188"/>
        <source>Start automatically when system starts</source>
        <translation>Starta automatiskt när datorn startar</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="195"/>
        <source>Only use landscape-oriented photos</source>
        <translation>Använd endast landskapsorienterade bilder</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="202"/>
        <source>Rotate images according to EXIF information</source>
        <translation>Rotera bilder enligt EXIF information</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="211"/>
        <source>View info on photo</source>
        <translation>Visa bildinformation</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="269"/>
        <source>View info in system tray tooltip</source>
        <translation>Visa information i menyraden</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="276"/>
        <source>Use full desktop area</source>
        <translation>Använd hela skrivbordet</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="285"/>
        <source>Photo has to be</source>
        <translation>Bilden ska vara</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="296"/>
        <source>independent of</source>
        <translation>oberoende av</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="301"/>
        <source>at least 1/2 of</source>
        <translation>åtminstone 1/2 av</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="306"/>
        <source>at least 3/4 of</source>
        <translation>åtminstone 3/4 av</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="311"/>
        <source>bigger than</source>
        <translation>större än</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="319"/>
        <source>desktop&apos;s size</source>
        <translation>skrivbordets storlek</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="381"/>
        <source>Store images in history for</source>
        <translation>Spara bilder i historiken i</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="398"/>
        <source>Clear</source>
        <translation>Rensa</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="433"/>
        <source>Direct connection</source>
        <translation>Direkt anslutning</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="443"/>
        <source>Proxy connection</source>
        <translation>Anslutning via proxy server</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="343"/>
        <source>Don&apos;t save locally remote photos if free disk space goes below</source>
        <translation>Spara inte nedladdade bilder lokalt om det fria hårddiskutrymmet understiger</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="630"/>
        <source>Engines</source>
        <translation>Moduler</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="750"/>
        <source>Available modules:</source>
        <translation>Tillgängliga moduler:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="757"/>
        <source>Active modules:</source>
        <translation>Aktiva moduler:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="421"/>
        <source>Network</source>
        <translation>Nätverk</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="467"/>
        <source>Use system proxy</source>
        <translation>Använd system proxy</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="477"/>
        <source>Use custom proxy</source>
        <translation>Använd en egen proxy konfiguration</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="497"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="547"/>
        <source>Authentication</source>
        <translation>Autentisering</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="562"/>
        <source>Username:</source>
        <translation>Användarnamn:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="579"/>
        <source>Password:</source>
        <translation>Lösenord:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="487"/>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="514"/>
        <source>Changes won&apos;t be applied. Are you sure?</source>
        <translation>Ändringar kommer inte att sparas. Är du säker?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="239"/>
        <source>Left</source>
        <translation>Vänster</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="240"/>
        <source>Right</source>
        <translation>Höger</translation>
    </message>
</context>
<context>
    <name>SmugMug::DialogWidget</name>
    <message>
        <location filename="../../src/smugmug.cpp" line="252"/>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <location filename="../../src/smugmug.cpp" line="275"/>
        <source>Edit SmugMug item</source>
        <translation>Redigera Smugmug objekt</translation>
    </message>
    <message>
        <location filename="../../src/smugmug.cpp" line="280"/>
        <source>Add SmugMug item</source>
        <translation>Lägg till ett Smugmug objekt</translation>
    </message>
</context>
<context>
    <name>SmugMug::Item</name>
    <message>
        <location filename="../../src/smugmug.cpp" line="47"/>
        <source>Text:</source>
        <translation>Text:</translation>
    </message>
</context>
<context>
    <name>SplashScreen</name>
    <message>
        <location filename="../../src/splash.cpp" line="46"/>
        <source>Author:</source>
        <translation>Upphovsman:</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="109"/>
        <source>Loading Files module ...</source>
        <translation>Laddar fil modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="116"/>
        <source>Loading Folders module ...</source>
        <translation>Laddar biblioteks modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="123"/>
        <source>Loading Flickr module ...</source>
        <translation>Laddar Flickr modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="137"/>
        <source>Loading Panoramio module ...</source>
        <translation>Laddar Panoramio modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="151"/>
        <source>Loading Ipernity module ...</source>
        <translation>Laddar Ipernity modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="158"/>
        <source>Loading Photobucket module ...</source>
        <translation>Laddar Photobucket modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="165"/>
        <source>Loading Buzznet module ...</source>
        <translation>Laddar Buzznet modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="172"/>
        <source>Loading Picasa module ...</source>
        <translation>Laddar Picasa modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="179"/>
        <source>Loading SmugMug module ...</source>
        <translation>Laddar Smugmug modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="193"/>
        <source>Loading Google module ...</source>
        <translation>Laddar Google modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="200"/>
        <source>Loading Vladstudio module ...</source>
        <translation>Laddar Vladstudio modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="207"/>
        <source>Loading deviantART module ...</source>
        <translation>Laddar deviantART modul ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="214"/>
        <source>Loading settings ...</source>
        <translation>Laddar inställningar ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="221"/>
        <source>Launching Wally ...</source>
        <translation>Startar Wally ...</translation>
    </message>
</context>
<context>
    <name>Viewer</name>
    <message>
        <location filename="../../ui/viewer.ui" line="9"/>
        <source>Right-click on photo to show actions</source>
        <translation>Högerklicka på foto för att se alternativ</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="63"/>
        <source>Fit to window</source>
        <translation>Anpassa till fönster</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="72"/>
        <source>Show full image</source>
        <translation>Visa originalstorlek</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="81"/>
        <source>Zoom in</source>
        <translation>Zooma in</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="90"/>
        <source>Zoom out</source>
        <translation>Zooma ut</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="99"/>
        <source>Rotate clockwise</source>
        <translation>Rotera medurs</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="108"/>
        <source>Rotate c. clockwise</source>
        <translation>Rotera moturs</translation>
    </message>
</context>
<context>
    <name>Vladstudio::DialogWidget</name>
    <message>
        <location filename="../../src/vladstudio.cpp" line="325"/>
        <source>All</source>
        <translation>Alla</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="326"/>
        <source>Abstract art</source>
        <translation>Abstrakt konst</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="327"/>
        <source>Creatures</source>
        <translation>Varelser</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="328"/>
        <source>Illustrations</source>
        <translation>Illustrationer</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="329"/>
        <source>Photos</source>
        <translation>Foton</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="334"/>
        <source>By ID</source>
        <translation>Från ID</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="335"/>
        <source>By view count</source>
        <translation>Från visningstillfällen</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="340"/>
        <source>Ascending</source>
        <translation>Stigande</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="341"/>
        <source>Descending</source>
        <translation>Avtagande</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="344"/>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="345"/>
        <source>Order:</source>
        <translation>Ordning:</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="346"/>
        <source>Direction:</source>
        <translation>Riktning:</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="368"/>
        <source>Edit Vladstudio item</source>
        <translation>Redigera Vladstudio objekt</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="375"/>
        <source>Add Vladstudio item</source>
        <translation>Lägg till ett Vladstudio objekt</translation>
    </message>
</context>
<context>
    <name>Vladstudio::Item</name>
    <message>
        <location filename="../../src/vladstudio.cpp" line="42"/>
        <source>All categories</source>
        <translation>Alla kategorier</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="46"/>
        <source>Abstract art</source>
        <translation>Abstrakt konst</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="50"/>
        <source>Creatures</source>
        <translation>Varelser</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="54"/>
        <source>Illustrations</source>
        <translation>Illustrationer</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="58"/>
        <source>Photos</source>
        <translation>Foton</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="89"/>
        <source>by Id</source>
        <translation>Från ID</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="93"/>
        <source>by view count</source>
        <translation>Från visningstillfällen</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="105"/>
        <source>ascending</source>
        <translation>stigande</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="109"/>
        <source>descending</source>
        <translation>avtagande</translation>
    </message>
</context>
<context>
    <name>Wally::Application</name>
    <message>
        <location filename="../../src/wally.cpp" line="621"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="623"/>
        <location filename="../../src/wally.cpp" line="2114"/>
        <source>Play</source>
        <translation>Kör</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="625"/>
        <location filename="../../src/wally.cpp" line="2094"/>
        <source>Pause</source>
        <translation>Paus</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="626"/>
        <source>Next photo</source>
        <translation>Nästa bild</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="627"/>
        <source>Save photo...</source>
        <translation>Spara foto...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="628"/>
        <source>Get EXIF info...</source>
        <translation>Hämta EXIF information...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="629"/>
        <source>Settings...</source>
        <translation>Inställningar...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="630"/>
        <source>Explore source</source>
        <translation>Utforska källa</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="631"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="632"/>
        <source>History...</source>
        <translation>Historik...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="633"/>
        <source>About Qt...</source>
        <translation>Om Qt...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="634"/>
        <source>Quit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="637"/>
        <source>English</source>
        <translation>Engelska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="638"/>
        <source>Italian</source>
        <translation>Italienska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="639"/>
        <source>Spanish</source>
        <translation>Spanska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="640"/>
        <source>German</source>
        <translation>Tyska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="641"/>
        <source>French</source>
        <translation>Franska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="642"/>
        <source>Russian</source>
        <translation>Ryska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="644"/>
        <source>Czech</source>
        <translation>Tjeckiska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="645"/>
        <source>Polish</source>
        <translation>Polska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="635"/>
        <source>Languages</source>
        <translation>Språk</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="646"/>
        <source>Chinese (Simplified)</source>
        <translation>Kinesiska (förenklad)</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="647"/>
        <source>Chinese (Traditional)</source>
        <translation>Kinesiska (traditionell)</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="648"/>
        <source>Catalan</source>
        <translation>Katalanska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="649"/>
        <source>Greek</source>
        <translation>Grekiska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="650"/>
        <source>Korean</source>
        <translation>Koreanska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="651"/>
        <source>Hungarian</source>
        <translation>Ungerska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="652"/>
        <source>Danish</source>
        <translation>Danska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="653"/>
        <source>Swedish</source>
        <translation>Svenska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="654"/>
        <source>Turkish</source>
        <translation>Turkiska</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1685"/>
        <source>Wally Error</source>
        <translation>Wally fel</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1685"/>
        <source>Active Desktop must be disabled</source>
        <translation>Aktivit skrivbord måste inaktiveras</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1774"/>
        <location filename="../../src/wally.cpp" line="2065"/>
        <source>by:</source>
        <translation>av:</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1783"/>
        <source>Location:</source>
        <translation>Plats:</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1791"/>
        <location filename="../../src/wally.cpp" line="2070"/>
        <source>Engine:</source>
        <translation>Motor:</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="2154"/>
        <location filename="../../src/wally.cpp" line="2157"/>
        <source>Save photo</source>
        <translation>Spara foto</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="2155"/>
        <location filename="../../src/wally.cpp" line="2159"/>
        <source>Images (*.png *.xpm *.jpg)</source>
        <translation>Bilder (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="2654"/>
        <source>Right-click to show main menu</source>
        <translation>Högerklicka för att visa huvudmeny</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="643"/>
        <source>Portuguese (Brazil)</source>
        <translation>Portugisiska (Brasilien)</translation>
    </message>
</context>
<context>
    <name>Yahoo::DialogWidget</name>
    <message>
        <location filename="../../src/yahoo.cpp" line="268"/>
        <source>All of these words</source>
        <translation>Alla dessa ord</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="269"/>
        <source>Any of these words</source>
        <translation>Vilket som helst av dessa ord</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="272"/>
        <source>Search for:</source>
        <translation>Sök efter:</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="277"/>
        <source>Filter content</source>
        <translation>Filtrera innehåll</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="297"/>
        <source>Yahoo! item</source>
        <translation>Yahoo! objekt</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="298"/>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>Ofiltrerat innehåll kan visa känsliga eller sexuellt anspelande foton</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="309"/>
        <source>Edit Yahoo! item</source>
        <translation>Redigera Yahoo! objekt</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="317"/>
        <source>Add Yahoo! item</source>
        <translation>Lägg till ett Yahoo! objekt</translation>
    </message>
</context>
<context>
    <name>Yahoo::Item</name>
    <message>
        <location filename="../../src/yahoo.cpp" line="56"/>
        <source>Tags:</source>
        <translation>Etiketter:</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="58"/>
        <source>and</source>
        <translation>och</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="58"/>
        <source>or</source>
        <translation>eller</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="61"/>
        <source>content filtered</source>
        <translation>filtrerat innehåll</translation>
    </message>
</context>
</TS>
